@@ -1,4 +1,4 @@
-"""bootstrap implementation of boxes
+"""bootstrap implementation of autoforms
 
 :organization: Logilab
 :copyright: 2013 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
