@@ -15,22 +15,9 @@ from cubicweb.web.views import basecomponents
 from cubicweb.uilib import js
 
 
-# handle automatic reload
-orig_render_impl = getattr(basecomponents.ApplLogo, '_original_render_impl_', None)
-if orig_render_impl is None:
-    # first time we land here
-    orig_render_impl = basecomponents.ApplLogo.render
-    basecomponents.ApplLogo._original_render_impl_ = orig_render_impl
-
-@monkeypatch(basecomponents.ApplLogo)
-def render(self, w):
-    w(u'<h1>')
-    self._original_render_impl_(w)
-    w(u'</h1>')
-
 basecomponents.CookieLoginComponent._html = (
     u'''<!--%s-->
-    <a title="%s" class="btn btn-default btn-info" data-toggle="modal"
+    <a title="%s" data-toggle="modal"
     href="#loginModal">%s</a>''')
 
 @monkeypatch(basecomponents.CookieLoginComponent)
@@ -40,7 +27,7 @@ def call(self):
     self._cw.add_onload(js.jQuery("body").append(
         self._cw.view('logform', rset=self.cw_rset, id=self.loginboxid,
                       klass='%s' % self.loginboxid, title=True,
-                      showmessage=False)))
+                      showmessage=False, showonload=False)))
 
 
 # NOTE: CW 3.18 may introduce render_messages(). This would be the
