@@ -9,4 +9,4 @@ __docformat__ = "restructuredtext en"
 
 from cubicweb.web.views import facets
 
-facets.FilterBox.bk_linkbox_template = u'<p class="btn btn-small btn-facet">%s</p>'
+facets.FilterBox.bk_linkbox_template = u'<p class="btn btn-default btn-sm btn-facet">%s</p>'
