@@ -57,11 +57,16 @@ class ModalFormRenderer(formrenderers.FormRenderer):
     button_bar_class = 'modal-footer'
 
     def open_form(self, form, values, **attrs):
-        html = [u'<div %(class)s" id="%(id)s" tabindex="-1" role="dialog">'
+        showmessage = values.get('showmessage') and self._cw.message
+        if values.get('showonload', False):
+            # show the `modal` dialog : initialized in
+            # basecomponents.CookieLoginComponent by showonload=True
+            self._cw.add_onload("$('#%s').modal('show')" % values['modal_id'])
+        html = [u'<div class="%(class)s" id="%(id)s" tabindex="-1" role="dialog">'
                 u'<div class="modal-dialog">'
                 u'<div class="modal-content">' %  {
                     'id': values['modal_id'],
-                    'class': u'class="modal fade in"' if not values.get('showmessage') else u'modal'}]
+                    'class': u'modal fade in' if showmessage else u'modal'}]
         html.append(super(ModalFormRenderer, self).open_form(form, values, **attrs))
         html.append((u'<div class="modal-header">\n'
                   u'<button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>\n'
@@ -70,10 +75,11 @@ class ModalFormRenderer(formrenderers.FormRenderer):
         return u'\n'.join(html)
 
     def render_content(self, w, form, values, showmessage=False):
+        self._cw.add_onload("$('.close').click(function () {$(this).parent().removeClass('in');});")
         w(u'<div class="modal-body">')
         if values.get('showmessage') and self._cw.message:
-            w(u'<div class="alert alert-danger fade in">%s'
-              u'<button class="close" data-dismiss="alert">x</button></div>' % self._cw.message)
+            w(u'<div class="alert alert-danger in">%s'
+              u'<button class="close">x</button></div>' % self._cw.message)
         if self.display_progress_div:
             w(u'<div id="progress">%s</div>' % self._cw._('validating...'))
         w(u'\n<fieldset>\n')
